.. include:: /ad/ad_attention.inc

.. warning::
   This module will be deprecated in favor of `plasmapy.analysis.swept_langmuir`.

.. _langmuir:

*****************
Langmuir analysis
*****************

.. currentmodule:: plasmapy.diagnostics.langmuir

.. automodapi:: plasmapy.diagnostics.langmuir

.. nbgallery::
    :caption: Examples

    /notebooks/diagnostics/langmuir_analysis
